@@ -1,7 +1,13 @@
 #!/usr/bin/env python
 
-import json
+try:
+    from collections import OrderedDict
+    import json
+except ImportError:
+    from ordereddict import OrderedDict
+    import simplejson as json
 
+import itertools
 import six
 
 from csvkit import CSVKitWriter
@@ -13,7 +19,7 @@ def parse_object(obj, path=''):
     Inspired by JSONPipe (https://github.com/dvxhouse/jsonpipe).
     """
     if isinstance(obj, dict):
-        iterator = obj.iteritems()
+        iterator = obj.items()
     elif isinstance(obj, (list, tuple)):
         iterator = enumerate(obj)
     else:
@@ -33,28 +39,23 @@ def json2csv(f, key=None, **kwargs):
 
     The top-level element of the input must be a list or a dictionary. If it is a dictionary, a key must be provided which is an item of the dictionary which contains a list.
     """
-    document = f.read()
-    js = json.loads(document)
+    js = json.load(f, object_pairs_hook=OrderedDict)
 
     if isinstance(js, dict):
         if not key:
             raise TypeError('When converting a JSON document with a top-level dictionary element, a key must be specified.')
-        
+
         js = js[key]
 
-    if not isinstance(js, list):
-        raise TypeError('Only JSON documents with a top-level list element are able to be converted (or a top-level dictionary if specifying a key).')
-
-    field_set = set()
+    fields = []
     flat = []
 
     for obj in js:
         flat.append(parse_object(obj)) 
 
-    for obj in flat:
-        field_set.update(obj.keys())
-
-    fields = sorted(list(field_set))
+        for key in obj.keys():
+            if key not in fields:
+                fields.append(key)
 
     o = six.StringIO()
     writer = CSVKitWriter(o)
@@ -65,10 +66,7 @@ def json2csv(f, key=None, **kwargs):
         row = []
 
         for field in fields:
-            if field in i:
-                row.append(i[field])
-            else:
-                row.append(None)
+            row.append(i.get(field, None))
 
         writer.writerow(row)
 
