@@ -4,4 +4,4 @@ def make_default_headers(n):
     """
     Make a set of simple, default headers for files that are missing them.
     """
-    return [u'column%i' % (i + 1) for i in range(n)]
+    return ['column%i' % (i + 1) for i in range(n)]
