@@ -56,9 +56,7 @@ class CSVLook(CSVKitUtility):
         # horizontal and vertical dividers.
         divider = '|--' + '-+-'.join('-'* w for w in widths) + '--|'
 
-        write = lambda t: self.output_file.write(t.encode('utf-8'))
-
-        write('%s\n' % divider)
+        self.output_file.write('%s\n' % divider)
 
         for i, row in enumerate(rows):
             output = []
@@ -68,10 +66,10 @@ class CSVLook(CSVKitUtility):
                     d = ''
                 output.append(' %s ' % six.text_type(d).ljust(widths[j]))
 
-            write('| %s |\n' % ('|'.join(output)))
+            self.output_file.write('| %s |\n' % ('|'.join(output)))
 
             if (i == 0 or i == len(rows) - 1):
-                write('%s\n' % divider)
+                self.output_file.write('%s\n' % divider)
 
 def launch_new_instance():
     utility = CSVLook()
